==> cabal-fmt-0.1.5.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/cabal-fmt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-cabal-fmt-z-cabal-fmt-internal
version:              0.1.5.1
package-name:         cabal-fmt
lib-name:             cabal-fmt-internal
id:                   cabal-fmt-0.1.5.1-2B7kohVJShnllabzUV7TY-cabal-fmt-internal
key:                  cabal-fmt-0.1.5.1-2B7kohVJShnllabzUV7TY-cabal-fmt-internal
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  5073e4c883ad7a345789d0c0a44c6394
exposed-modules:
    CabalFmt CabalFmt.Comments CabalFmt.Error CabalFmt.Fields
    CabalFmt.Fields.BuildDepends CabalFmt.Fields.Extensions
    CabalFmt.Fields.Modules CabalFmt.Fields.SourceFiles
    CabalFmt.Fields.TestedWith CabalFmt.Glob CabalFmt.Monad
    CabalFmt.Options CabalFmt.Parser CabalFmt.Pragma CabalFmt.Prelude
    CabalFmt.Refactoring CabalFmt.Refactoring.ExpandExposedModules
    CabalFmt.Refactoring.Fragments CabalFmt.Refactoring.GlobFiles
    CabalFmt.Refactoring.Type

import-dirs:          /usr/lib/ghc-9.0.1/site-local/cabal-fmt-0.1.5.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cabal-fmt-0.1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/cabal-fmt-0.1.5.1
hs-libraries:
    HScabal-fmt-0.1.5.1-2B7kohVJShnllabzUV7TY-cabal-fmt-internal

depends:
    Cabal-3.4.0.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cabal-fmt-0.1.5.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/cabal-fmt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-cabal-fmt-z-cabal-fmt-internal
version:              0.1.5.1
package-name:         cabal-fmt
lib-name:             cabal-fmt-internal
id:                   cabal-fmt-0.1.5.1-G8tX1kpGHrNE3bZQ9uC7Hd-cabal-fmt-internal
key:                  cabal-fmt-0.1.5.1-G8tX1kpGHrNE3bZQ9uC7Hd-cabal-fmt-internal
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  107c09a6ebb66ffdfabd3e637a8c9e8f
exposed-modules:
    CabalFmt CabalFmt.Comments CabalFmt.Error CabalFmt.Fields
    CabalFmt.Fields.BuildDepends CabalFmt.Fields.Extensions
    CabalFmt.Fields.Modules CabalFmt.Fields.SourceFiles
    CabalFmt.Fields.TestedWith CabalFmt.Glob CabalFmt.Monad
    CabalFmt.Options CabalFmt.Parser CabalFmt.Pragma CabalFmt.Prelude
    CabalFmt.Refactoring CabalFmt.Refactoring.ExpandExposedModules
    CabalFmt.Refactoring.Fragments CabalFmt.Refactoring.GlobFiles
    CabalFmt.Refactoring.Type

import-dirs:          /usr/lib/ghc-9.0.1/site-local/cabal-fmt-0.1.5.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/cabal-fmt-0.1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/cabal-fmt-0.1.5.1
hs-libraries:
    HScabal-fmt-0.1.5.1-G8tX1kpGHrNE3bZQ9uC7Hd-cabal-fmt-internal

depends:
    Cabal-3.4.0.0 base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
